/* ------------------------------------------------------------------------- */
/*                                                                           */
/* Copyright (c) 2003 The Open Group                                         */
/*                                                                           */
/* Permission is hereby granted, free of charge, to any person obtaining a   */
/* copy of this software (the "Software"), to deal in the Software without   */
/* restriction, including without limitation the rights to use, copy,        */
/* modify, merge, publish, distribute, sublicense, and/or sell copies of     */
/* the Software, and to permit persons to whom the Software is furnished     */
/* to do so, subject to the following conditions:                            */
/*                                                                           */
/* The above copyright notice and this permission notice shall be included   */
/* in all copies or substantial portions of the Software.                    */
/*                                                                           */
/* THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS   */
/* OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF                */
/* MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.    */
/* IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY      */
/* CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT */
/* OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR  */
/* THE USE OR OTHER DEALINGS IN THE SOFTWARE.                                */
/*                                                                           */
/* ------------------------------------------------------------------------- */
/*                                                                           */
/* File revision information                                                 */
/*                                                                           */
/* $Source: /mnt/cvslocal/sdk4/java/org/opengroup/arm40/metric/ArmMetric.java,v $ */
/* $Revision: 1.1 $ */
/* $Date: 2005/03/14 15:14:53 $ */
/*                                                                           */
/* ------------------------------------------------------------------------- */

package org.opengroup.arm40.metric;

import org.opengroup.arm40.transaction.ArmInterface;

/**
 * The superclass for all the metric interfaces. 
 * 
 * The common behavior of all metric subclasses is:
 * <ul>
 * <li>
 * <code>getDefinition()</code> returns the descriptive metadata 
 * (name, units, usage, ID) about the metric.
 * The returned object will be the appropriate subclass of 
 * <code>ArmMetricDefinition</code>
 * </li>
 * <li>
 * Each subclass is also expected to implement <code>get()</code> and 
 * <code>set()</code> methods that 
 * take and/or return data of the appropriate type for the subclass. 
 * These methods are not defined in this interface because they have different 
 * signatures, depending on the type of metric. 
 * </li>
 * </ul>
 * Objects that implement a subclass of <code>ArmMetric</code> are used with 
 * {@link ArmTransactionWithMetrics} and / or 
 * {@link ArmTranReportWithMetrics}. They are bound via 
 * {@link ArmMetricGroup} when the <code>ArmTransactionWithMetrics</code>
 * or <code>ArmTranReportWithMetrics</code> instance is created. Each 
 * <code>ArmMetric</code> instance can be bound to any number of transaction 
 * instances.<p/> 
 * Setting the value of the <code>ArmMetric</code>
 * instance effectively sets the value for all the transaction instances 
 * to which it is bound. The value affects each 
 * <code>ArmTransactionWithMetrics</code> instance the next time a 
 * <code>start()</code>, <code>update()</code>, or <code>stop()</code> is 
 * executed on the instance. The value affects each 
 * <code>ArmTranReportWithMetrics</code> instance the next time a 
 * <code>report()</code> is executed on the instance.
 * <p/> 
 * This class cannot be instantiated. Objects that implement a subclass of 
 * <code>ArmMetric</code> are created using the <code>newArmMetric...()</code> 
 * methods of {@link ArmMetricFactory}.
 * 
 * @author ARM Working Group of The Open Group
 */

public interface ArmMetric extends ArmInterface {

// No Public Constructors

// Public Instance Methods

    /**
     * @return the descriptive metadata
     * (name, units, usage, ID) about the metric.
     */
    public ArmMetricDefinition getDefinition();
}
