/* ------------------------------------------------------------------------- */
/*                                                                           */
/* Copyright (c) 2003 The Open Group                                         */
/*                                                                           */
/* Permission is hereby granted, free of charge, to any person obtaining a   */
/* copy of this software (the "Software"), to deal in the Software without   */
/* restriction, including without limitation the rights to use, copy,        */
/* modify, merge, publish, distribute, sublicense, and/or sell copies of     */
/* the Software, and to permit persons to whom the Software is furnished     */
/* to do so, subject to the following conditions:                            */
/*                                                                           */
/* The above copyright notice and this permission notice shall be included   */
/* in all copies or substantial portions of the Software.                    */
/*                                                                           */
/* THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS   */
/* OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF                */
/* MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.    */
/* IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY      */
/* CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT */
/* OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR  */
/* THE USE OR OTHER DEALINGS IN THE SOFTWARE.                                */
/*                                                                           */
/* ------------------------------------------------------------------------- */
/*                                                                           */
/* File revision information                                                 */
/*                                                                           */
/* $Source: /mnt/cvslocal/sdk4/java/org/opengroup/arm40/metric/ArmMetricDefinition.java,v $ */
/* $Revision: 1.1 $ */
/* $Date: 2005/03/14 15:14:53 $ */
/*                                                                           */
/* ------------------------------------------------------------------------- */

package org.opengroup.arm40.metric;

/* to be added in the future for getApplicationDefinition()
 * import org.opengroup.arm40.transaction.ArmApplicationDefinition;
 */

import org.opengroup.arm40.transaction.ArmInterface;
import org.opengroup.arm40.transaction.ArmID;

/**
 * The superclass for all the metric definition interfaces. 
 * All the methods are defined in <code>ArmMetricDefinition</code>. 
 * The subclasses serve as markers for the data types. 
 * All the publicly accessible attributes are immutable and have a getter 
 * method for them.
 * <p/>
 * The attributes are:
 * <ul>
 * <li>
 * The <b>definition</b> of the application that contains the 
 * transaction. 
 * It must not be null.
 * </li>
 * <li>
 * <b>Name</b>. The maximum length is 127 characters. 
 * The name must not be null or zero-length.
 * </li>
 * <li>
 * <b>Units</b>. An optional string describing the units of measurement, 
 * such as "files" or "jobs in queue". It may be null.
 * </li>
 * <li>
 * <b>Usage</b>. Describes any additional information about the semantics 
 * of the metric. Most metrics will be classified as "general", 
 * indicating that there is no specific semantic 
 * declared. The two specific semantics are the size of the transaction, 
 * such as the number of files that were backed up, and a status 
 * that could contain data, such as an error code that 
 * describes why a transaction failed. 
 * See the field descriptions of <code>METRIC_USE_...</code> below for 
 * the defined values. Any negative value is also permitted; 
 * the negative range is reserved for application-specific values. 
 * </li>
 * <li>
 * Optional <b>ID</b>. An optional 16-byte ID may be associated with the 
 * identity of a metric definition. The returned value, which 
 * could be null, is the same value passed to the factory 
 * method 
 * [e.g., {@link ArmMetricFactory#newArmMetricCounter32Definition}].
 * The ID value is bound to a unique combination of the metric format 
 * (e.g., Counter32), name, usage, and unit properties. When provided, 
 * the ID may be used as a concise alias for the unique combination. 
 * It may be null. 
 * </li>
 * </ul> 
 * <p/> 
 * This class cannot be instantiated. Objects that implement a subclass of 
 * <code>ArmMetricDefinition</code> are created using the 
 * <code>newArmMetric...Definition()</code> 
 * methods of {@link ArmMetricFactory}.
 *  
 * @author ARM Working Group of The Open Group
 */
public interface ArmMetricDefinition extends ArmInterface {

// No Public Constructors

// Constants

    /**
     * No specific usage semantics are declared.
     */
    public static final short METRIC_USE_GENERAL = 0;

    /**
     * Metric represents the "size" of the transaction
     * (counter & gauge only).
     */
    public static final short METRIC_USE_TRAN_SIZE = 1;

    /**
     * Metric represents status, like an error code
     * (numeric ID & string only).
     */
    public static final short METRIC_USE_TRAN_STATUS = 2;

// Public Instance Methods 

    /* TO BE ADDED IN A FUTURE ISSUE 
     * Gets the definition of the containig application.
     * @return the application definition.
    public ArmApplicationDefinition getApplicationDefinition();
     */
    
    /**
     * Gets the (optional) ID for this definition.
     * @return the ID or <code>null</code>.
     */
    public ArmID getID();

    /**
     * Gets the name of this definition.
     * @return the definition name.
     */
    public String getName();

    /**
     * Gets the (optional) units description.
     * @return the units desciption or <code>null</code>.
     */
    public String getUnits();

    /**
     * Gets the usage semantics.
     * @return One of {@link #METRIC_USE_GENERAL}, 
     * {@link #METRIC_USE_TRAN_SIZE},
     * {@link #METRIC_USE_TRAN_STATUS}, 
     * or an application-specific negative value.
     */
    public short getUsage();

}
