/* ------------------------------------------------------------------------- */
/*                                                                           */
/* Copyright (c) 2003 The Open Group                                         */
/*                                                                           */
/* Permission is hereby granted, free of charge, to any person obtaining a   */
/* copy of this software (the "Software"), to deal in the Software without   */
/* restriction, including without limitation the rights to use, copy,        */
/* modify, merge, publish, distribute, sublicense, and/or sell copies of     */
/* the Software, and to permit persons to whom the Software is furnished     */
/* to do so, subject to the following conditions:                            */
/*                                                                           */
/* The above copyright notice and this permission notice shall be included   */
/* in all copies or substantial portions of the Software.                    */
/*                                                                           */
/* THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS   */
/* OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF                */
/* MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.    */
/* IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY      */
/* CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT */
/* OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR  */
/* THE USE OR OTHER DEALINGS IN THE SOFTWARE.                                */
/*                                                                           */
/* ------------------------------------------------------------------------- */
/*                                                                           */
/* File revision information                                                 */
/*                                                                           */
/* $Source: /mnt/cvslocal/sdk4/java/org/opengroup/arm40/metric/ArmMetricFactory.java,v $ */
/* $Revision: 1.1 $ */
/* $Date: 2005/03/14 15:14:53 $ */
/*                                                                           */
/* ------------------------------------------------------------------------- */

package org.opengroup.arm40.metric;

import org.opengroup.arm40.transaction.ArmInterface;
import org.opengroup.arm40.transaction.ArmApplicationDefinition;
import org.opengroup.arm40.transaction.ArmApplication;
import org.opengroup.arm40.transaction.ArmID;
import org.opengroup.arm40.transaction.ArmIdentityPropertiesTransaction;
import org.opengroup.arm40.transaction.ArmErrorCallback;

/**
 * Provides methods to create instances of the classes in 
 * the org.opengroup.arm40.metric package. An error callback method can 
 * be registered for objects created with this factory (see 
 * {@link #setErrorCallback(ArmErrorCallback)}). For additional 
 * details about error handling philosophy see the description
 * in {@link org.opengroup.arm40.transaction.ArmTransactionFactory}.
 * <p/>
 * Semantics of the factory methods are provided in the description 
 * of the individual methods below.  
 * <p/>
 * 
 * <code>ArmMetricFactory</code> is instantiated using a class loader. 
 * The actual name of the factory implementation class is obtained from the 
 * system property whose name is provided in the 
 * {@link #propertyKey} constant.   
 * 
 * @author ARM Working Group of The Open Group
 */
public interface ArmMetricFactory extends ArmInterface {

// Public Constants

    /**
     * name of system property holding the implementation class name.
     */
    public static final String propertyKey = "Arm40.ArmMetricFactory";

// Public Instance Methods

/* --- metric definitions --- */

    /** Creates a new metadata instance.
     * @param app metadata about the containing application.
     * @param name name for this definition.
     * @param units units descrioption, or <code>null</code>.
     * @param usage One of 
     *              {@link ArmMetricDefinition#METRIC_USE_GENERAL}, 
     *              {@link ArmMetricDefinition#METRIC_USE_TRAN_SIZE},
     *              {@link ArmMetricDefinition#METRIC_USE_TRAN_STATUS}, 
     *              or an application-specific negative value.
     * @param id ID provided by the application for this metric definition, 
     *           or <code>null</code>.
     * @return a new metadata instance for this definition.
     * @see ArmMetricDefinition
     */
    public ArmMetricCounter32Definition newArmMetricCounter32Definition(
        ArmApplicationDefinition app, String name, String units, 
        short usage, ArmID id);

    /** Creates a new metadata instance.
     * @param app metadata about the containing application.
     * @param name name for this definition.
     * @param units units descrioption, or <code>null</code>.
     * @param usage One of 
     *              {@link ArmMetricDefinition#METRIC_USE_GENERAL}, 
     *              {@link ArmMetricDefinition#METRIC_USE_TRAN_SIZE},
     *              {@link ArmMetricDefinition#METRIC_USE_TRAN_STATUS}, 
     *              or an application-specific negative value.
     * @param id ID provided by the application for this metric definition, 
     *           or <code>null</code>.
     * @return a new metadata instance for this definition.
     */
    public ArmMetricCounter64Definition newArmMetricCounter64Definition(
        ArmApplicationDefinition app, String name, String units, 
        short usage, ArmID id);

    /** Creates a new metadata instance.
     * @param app metadata about the containing application.
     * @param name name for this definition.
     * @param units units descrioption, or <code>null</code>.
     * @param usage One of 
     *              {@link ArmMetricDefinition#METRIC_USE_GENERAL}, 
     *              {@link ArmMetricDefinition#METRIC_USE_TRAN_SIZE},
     *              {@link ArmMetricDefinition#METRIC_USE_TRAN_STATUS}, 
     *              or an application-specific negative value.
     * @param id ID provided by the application for this metric definition, 
     *           or <code>null</code>.
     * @return a new metadata instance for this definition.
     */
    public ArmMetricCounterFloat32Definition 
        newArmMetricCounterFloat32Definition(
            ArmApplicationDefinition app, String name, String units,
            short usage, ArmID id);

    /** Creates a new metadata instance.
     * @param app metadata about the containing application.
     * @param name name for this definition.
     * @param units units descrioption, or <code>null</code>.
     * @param usage One of 
     *              {@link ArmMetricDefinition#METRIC_USE_GENERAL}, 
     *              {@link ArmMetricDefinition#METRIC_USE_TRAN_SIZE},
     *              {@link ArmMetricDefinition#METRIC_USE_TRAN_STATUS}, 
     *              or an application-specific negative value.
     * @param id ID provided by the application for this metric definition, 
     *           or <code>null</code>.
     * @return a new metadata instance for this definition.
     */
    public ArmMetricGauge32Definition newArmMetricGauge32Definition(
        ArmApplicationDefinition app, String name, String units, 
        short usage, ArmID id);

    /** Creates a new metadata instance.
     * @param app metadata about the containing application.
     * @param name name for this definition.
     * @param units units descrioption, or <code>null</code>.
     * @param usage One of 
     *              {@link ArmMetricDefinition#METRIC_USE_GENERAL}, 
     *              {@link ArmMetricDefinition#METRIC_USE_TRAN_SIZE},
     *              {@link ArmMetricDefinition#METRIC_USE_TRAN_STATUS}, 
     *              or an application-specific negative value.
     * @param id ID provided by the application for this metric definition, 
     *           or <code>null</code>.
     * @return a new metadata instance for this definition.
     */
    public ArmMetricGauge64Definition newArmMetricGauge64Definition(
        ArmApplicationDefinition app, String name, String units, 
        short usage, ArmID id);

    /** Creates a new metadata instance.
     * @param app metadata about the containing application.
     * @param name name for this definition.
     * @param units units descrioption, or <code>null</code>.
     * @param usage One of 
     *              {@link ArmMetricDefinition#METRIC_USE_GENERAL}, 
     *              {@link ArmMetricDefinition#METRIC_USE_TRAN_SIZE},
     *              {@link ArmMetricDefinition#METRIC_USE_TRAN_STATUS}, 
     *              or an application-specific negative value.
     * @param id ID provided by the application for this metric definition, 
     *           or <code>null</code>.
     * @return a new metadata instance for this definition.
     */
    public ArmMetricGaugeFloat32Definition 
        newArmMetricGaugeFloat32Definition(
            ArmApplicationDefinition app, String name, String units,
            short usage, ArmID id);

    /** Creates a new metadata instance.
     * @param app metadata about the containing application.
     * @param name name for this definition.
     * @param units units descrioption, or <code>null</code>.
     * @param usage One of 
     *              {@link ArmMetricDefinition#METRIC_USE_GENERAL}, 
     *              {@link ArmMetricDefinition#METRIC_USE_TRAN_SIZE},
     *              {@link ArmMetricDefinition#METRIC_USE_TRAN_STATUS}, 
     *              or an application-specific negative value.
     * @param id ID provided by the application for this metric definition, 
     *           or <code>null</code>.
     * @return a new metadata instance for this definition.
     */
    public ArmMetricNumericId32Definition newArmMetricNumericId32Definition(
        ArmApplicationDefinition app, String name, String units,
        short usage, ArmID id);

    /** Creates a new metadata instance.
     * @param app metadata about the containing application.
     * @param name name for this definition.
     * @param units units descrioption, or <code>null</code>.
     * @param usage One of 
     *              {@link ArmMetricDefinition#METRIC_USE_GENERAL}, 
     *              {@link ArmMetricDefinition#METRIC_USE_TRAN_SIZE},
     *              {@link ArmMetricDefinition#METRIC_USE_TRAN_STATUS}, 
     *              or an application-specific negative value.
     * @param id ID provided by the application for this metric definition, 
     *           or <code>null</code>.
     * @return a new metadata instance for this definition.
     */
    public ArmMetricNumericId64Definition newArmMetricNumericId64Definition(
        ArmApplicationDefinition app, String name, String units, 
        short usage, ArmID id);

    /** Creates a new metadata instance.
     * @param app metadata about the containing application.
     * @param name name for this definition.
     * @param units units descrioption, or <code>null</code>.
     * @param usage One of 
     *              {@link ArmMetricDefinition#METRIC_USE_GENERAL}, 
     *              {@link ArmMetricDefinition#METRIC_USE_TRAN_SIZE},
     *              {@link ArmMetricDefinition#METRIC_USE_TRAN_STATUS}, 
     *              or an application-specific negative value.
     * @param id ID provided by the application for this metric definition, 
     *           or <code>null</code>.
     * @return a new metadata instance for this definition.
     */
    public ArmMetricString32Definition newArmMetricString32Definition(
        ArmApplicationDefinition app, String name, String units, 
        short usage, ArmID id);


/* --- other definitions --- */

    /**
     * Creates an ordered set of <code>ArmMetricDefinition</code> subclasses 
     * ready for binding to transaction definition objects.
     * 
     * 
     * @param definitions An array of ArmMetricDefinition objects. 
     * <p/>
     * The ordering in the array is important. The array can have up to 
     * seven elements and is position-sensitive. To remain consistent with 
     * ARM 2.0, any <code>ArmMetricDefinition</code> subclass except 
     * <code>ArmMetricString32Definition</code> can be assigned to 
     * elements <code>0:5</code> and only 
     * <code>ArmMetricString32Definition</code> can be assigned to element 
     * <code>6</code>. 
     * <p/>
     * Any element can be null. If the input array has fewer
     * than seven elements, the rest of the elements are assigned a value of 
     * <code>null</code>. The array can be sparsely populated. 
     * For example, there can be a non-<code>null</code> 
     * <code>ArmMetricDefinition</code> reference in element <code>0</code>
     * and <code>6</code>, and <code>null</code> references in elements 
     * <code>1:5</code>.
     * 
     * @return a new metadata instance for the metric definition group.
     */
	public ArmMetricGroupDefinition newArmMetricGroupDefinition(
        ArmMetricDefinition[] definitions);

    /**
     * Creates an object that contains the metadata about a transaction.
     * 
     * Details about the metadata are found in the 
     * {@link org.opengroup.arm40.transaction.ArmTransactionDefinition} 
     * section. In addition, a binding to a set of metadata about 
     * metrics is added via an {@link ArmMetricGroupDefinition} object.
     * @param app metadata about the containing application.
     * @param name name for this definition.
     * @param identityProperties an initialized  set of identity properties.
     * @param definition the metric definitions to be used with this 
     *        transaction.
     * @param id ID provided by the application for this transaction
     *           definition, or <code>null</code>.
     * @return a new metadata instance for a transaction associated 
     * with metrics. 
     */
    public ArmTransactionWithMetricsDefinition 
        newArmTransactionWithMetricsDefinition(
            ArmApplicationDefinition app, String name, 
            ArmIdentityPropertiesTransaction identityProperties, 
            ArmMetricGroupDefinition definition, ArmID id);


/* --- metric instances --- */

    /**
     * Creates a new metric instance.
     * @param definition the metadata describing this metric.
     * @return a new metric instance.
     */
    public ArmMetricCounter32 newArmMetricCounter32(
        ArmMetricCounter32Definition definition);

    /**
     * Creates a new metric instance.
     * @param definition the metadata describing this metric.
     * @return a new metric instance.
     */
    public ArmMetricCounter64 newArmMetricCounter64(
        ArmMetricCounter64Definition definition);

    /**
     * Creates a new metric instance.
     * @param definition the metadata describing this metric.
     * @return a new metric instance.
     */
    public ArmMetricCounterFloat32 newArmMetricCounterFloat32(
        ArmMetricCounterFloat32Definition definition);

    /**
     * Creates a new metric instance.
     * @param definition the metadata describing this metric.
     * @return a new metric instance.
     */
    public ArmMetricGauge32 newArmMetricGauge32(
        ArmMetricGauge32Definition definition);

    /**
     * Creates a new metric instance.
     * @param definition the metadata describing this metric.
     * @return a new metric instance.
     */
    public ArmMetricGauge64 newArmMetricGauge64(
        ArmMetricGauge64Definition definition);

    /**
     * Creates a new metric instance.
     * @param definition the metadata describing this metric.
     * @return a new metric instance.
     */
    public ArmMetricGaugeFloat32 newArmMetricGaugeFloat32(
        ArmMetricGaugeFloat32Definition definition);

    /**
     * Creates a new metric instance.
     * @param definition the metadata describing this metric.
     * @return a new metric instance.
     */
    public ArmMetricNumericId32 newArmMetricNumericId32(
        ArmMetricNumericId32Definition definition);

    /**
     * Creates a new metric instance.
     * @param definition the metadata describing this metric.
     * @return a new metric instance.
     */
    public ArmMetricNumericId64 newArmMetricNumericId64(
        ArmMetricNumericId64Definition definition);

    /**
     * Creates a new metric instance.
     * @param definition the metadata describing this metric.
     * @return a new metric instance.
     */
    public ArmMetricString32 newArmMetricString32(
        ArmMetricString32Definition definition);


/* --- other instances --- */
    /**
     * Creates an ordered set of <code>ArmMetric</code> subclasses 
     * ready for binding to transaction objects.
     * 
     * @param groupDefinition metadata object describing the metrics
     *        provided through the <code>metrics</code> parameter.
     * @param metrics an array of {@link ArmMetric} objects.
     * <p/>
     * The ordering in the array is important. The array can have up to 
     * seven elements and is position-sensitive. To remain consistent 
     * with ARM 2.0, any <code>ArmMetric</code> subclass except 
     * <code>ArmMetricString32</code> can be assigned to elements 
     * <code>0:5</code> and only <code>ArmMetricString32</code> can be 
     * assigned to element <code>6</code>. The 
     * <code>ArmMetricDefinition</code> objects associated with each 
     * <code>ArmMetric</code> object must have the exact same values as
     * the <code>ArmMetricDefinition</code> objects associated with 
     * the <code>ArmMetricGroupDefinition</code> object 
     * (they will often be the same objects, though this is not mandatory).
     * <p/>
     * Any element can be <code>null</code>. If the input array has fewer 
     * than seven elements, the rest of the elements are assigned a value 
     * of <code>null</code>. The array can be sparsely populated. 
     * For example, there can be a non-<code>null</code> 
     * <code>ArmMetric</code> reference in element <code>0</code> and 
     * <code>6</code>, and <code>null</code> references in elements 
     * <code>1:5</code>. 
     * 
     * @return a new metric group instance.
     */
    public ArmMetricGroup newArmMetricGroup(
        ArmMetricGroupDefinition groupDefinition, ArmMetric[] metrics);

    /**
     * Creates an object that represents an instance of a transaction
     * with an <code>ArmTranReport</code> interface.
     * 
     * @param app instance of the containing application (scope).
     * @param definition metadata about the transaction.
     * @param group metrics binding object. 
     * <p/>
     * If the metric group reference is null, the resulting 
     * <code>ArmTranReportWithMetrics</code> has no metrics, so it 
     * would have no more functions than an <code>ArmTranReport</code> 
     * object, except to return null to the 
     * {@link ArmTranReportWithMetrics#getMetricGroup} method. 
     * 
     * @return a new transaction instance associated with metrics. 
     */
    public ArmTranReportWithMetrics newArmTranReportWithMetrics(
        ArmApplication app, ArmTransactionWithMetricsDefinition definition, 
        ArmMetricGroup group);

    /**
     * Creates an object that represents an instance of a transaction.
     * 
     * @param app instance of the containing application (scope).
     * @param definition metadata about the transaction.
     * @param group metrics binding object. 
     * <p/>
     * If the metric group reference is null, the resulting 
     * <code>ArmTranReportWithMetrics</code> has no metrics, so it 
     * would have no more functions than an <code>ArmTranReport</code> 
     * object, except to return null to the 
     * {@link ArmTranReportWithMetrics#getMetricGroup} method. 
     * 
     * @return a new transaction instance associated with metrics. 
     */
    public ArmTransactionWithMetrics newArmTransactionWithMetrics(
        ArmApplication app, ArmTransactionWithMetricsDefinition definition,
        ArmMetricGroup group);

    /**
     * Registers an error callback for objects created through this factory.
     * See the error handling philosophy comment in the description of
     * {@link org.opengroup.arm40.transaction.ArmTransactionFactory}.
     *   
     * @param errorCallback an application object implementing the
     * <code>ArmErrorCallback> interface.
     * @return <code>true</code> if registration is accepted.
     * @see org.opengroup.arm40.transaction.ArmTransactionFactory#setErrorCallback
     */
    public boolean setErrorCallback(ArmErrorCallback errorCallback);
}
