/* ------------------------------------------------------------------------- */
/*                                                                           */
/* Copyright (c) 2003 The Open Group                                         */
/*                                                                           */
/* Permission is hereby granted, free of charge, to any person obtaining a   */
/* copy of this software (the "Software"), to deal in the Software without   */
/* restriction, including without limitation the rights to use, copy,        */
/* modify, merge, publish, distribute, sublicense, and/or sell copies of     */
/* the Software, and to permit persons to whom the Software is furnished     */
/* to do so, subject to the following conditions:                            */
/*                                                                           */
/* The above copyright notice and this permission notice shall be included   */
/* in all copies or substantial portions of the Software.                    */
/*                                                                           */
/* THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS   */
/* OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF                */
/* MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.    */
/* IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY      */
/* CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT */
/* OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR  */
/* THE USE OR OTHER DEALINGS IN THE SOFTWARE.                                */
/*                                                                           */
/* ------------------------------------------------------------------------- */
/*                                                                           */
/* File revision information                                                 */
/*                                                                           */
/* $Source: /mnt/cvslocal/sdk4/java/org/opengroup/arm40/metric/ArmMetricGroup.java,v $ */
/* $Revision: 1.1 $ */
/* $Date: 2005/03/14 15:14:53 $ */
/*                                                                           */
/* ------------------------------------------------------------------------- */

package org.opengroup.arm40.metric;

import org.opengroup.arm40.transaction.ArmInterface;

/**
 * Is used to bind objects that implement a subclass of 
 * <code>ArmMetric</code> to an
 * <code>ArmTransactionWithMetricsDefinition</code> or
 * <code>ArmTranReportWithMetricsDefinition</code> object.
 * 
 * The binding occurs when the transaction object is created using 
 * <code>newArmTransactionWithMetrics()</code> or 
 * <code>newArmTranReportWithMetrics()</code> and is immutable 
 * afterwards.
 * <p/> 
 * For all methods taking an <code>index</code> parameter, this
 * is the index into the <code>ArmMetric</code> array. 
 * It must have a value in the range 0:6. To remain consistent with 
 * ARM 2.0, any <code>ArmMetric</code> subclass except 
 * <code>ArmMetricString32</code> can be assigned to elements 0:5 
 * and only <code>ArmMetricString32</code> can be assigned to element 6.
 * <p/>
 * Objects implementing this interface are created using 
 * {@link ArmMetricFactory#newArmMetricGroup}.
 * 
 * @author ARM Working Group of The Open Group
 */

public interface ArmMetricGroup extends ArmInterface {

// No Public Constructors

// Public Instance Methods

    /**
     * @return the metric group definition used to create this object.
     */
    public ArmMetricGroupDefinition getDefinition();

    /**
     * @param index the index into the <code>ArmMetric</code> array. See
     * comment in the interface description above.
     * @return the metric at the array index. This value may be null.
     */
    public ArmMetric getMetric(int index);

    /**
     * @param index the index into the <code>ArmMetric</code> array. See
     * comment in the interface description above.
     * @return whether an ArmMetric subclass at this array index is valid.
     */
    public boolean isMetricValid(int index);

    /**
     * Indicates whether an <code>ArmMetric</code> subclass at this array 
     * index is valid.
     * This applies when any of the following calls are made:
     * <ul>
     * <li><code>ArmTranReportWithMetrics: report()</code></li>
     * <li><code>ArmTransactionWithMetrics: start(), update(), 
     * stop()</code></li>
     * </ul>
     *  
     * @param index index the index into the <code>ArmMetric</code> array. See
     * comment in the interface description above.
     * @param value If the valid flag is set then the metric value is 
     * processed.
     * @return 0 on sucess; otherwise, a non-zero error code is returned 
     * (as specified in {@link org.opengroup.arm40.transaction.ArmInterface}).
     */
    public int setMetricValid(int index, boolean value);
}
