/* ------------------------------------------------------------------------- */
/*                                                                           */
/* Copyright (c) 2003 The Open Group                                         */
/*                                                                           */
/* Permission is hereby granted, free of charge, to any person obtaining a   */
/* copy of this software (the "Software"), to deal in the Software without   */
/* restriction, including without limitation the rights to use, copy,        */
/* modify, merge, publish, distribute, sublicense, and/or sell copies of     */
/* the Software, and to permit persons to whom the Software is furnished     */
/* to do so, subject to the following conditions:                            */
/*                                                                           */
/* The above copyright notice and this permission notice shall be included   */
/* in all copies or substantial portions of the Software.                    */
/*                                                                           */
/* THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS   */
/* OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF                */
/* MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.    */
/* IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY      */
/* CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT */
/* OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR  */
/* THE USE OR OTHER DEALINGS IN THE SOFTWARE.                                */
/*                                                                           */
/* ------------------------------------------------------------------------- */
/*                                                                           */
/* File revision information                                                 */
/*                                                                           */
/* $Source: /mnt/cvslocal/sdk4/java/org/opengroup/arm40/metric/ArmMetricString32.java,v $ */
/* $Revision: 1.1 $ */
/* $Date: 2005/03/14 15:14:53 $ */
/*                                                                           */
/* ------------------------------------------------------------------------- */

package org.opengroup.arm40.metric;

/**
 * Implements a string of 1 to 32 characters. 
 * It is the same as ARM 2.0 metric type=10 (<code>ARM_String32</code>),
 *  with two differences:
 * <ul>
 * <li>
 * The characters are in the Java standard UCS-2 format.
 * </li>
 * <li>
 * The limit of 32 in the ARM 2.0 C language interface is a byte limit. 
 * The limit in the ARM 4.0 C bindings is a character limit. Because a 
 * character may be represented by more than one byte (e.g., a character 
 * in UTF-8 is represented as 1, 2, or 3 bytes), the ARM 4.0 C 
 * metric may be longer than 32 bytes.
 * </li>
 * </ul>
 * 
 * <p/>
 * Objects implementing this interface are created using 
 * {@link ArmMetricFactory#newArmMetricString32}.
 *   
 * @author ARM Working Group of The Open Group
 */

public interface ArmMetricString32 extends ArmMetric {

// No Public Constructors

// Public Instance Methods

	/**
     * Gets the string value.
     * @return the string value.
     */
    public String get();

    /**
     * Sets the string value.
     * @param s new string value.
     * @return 0 on sucess; otherwise, a non-zero error code is returned 
     * (as specified in {@link org.opengroup.arm40.transaction.ArmInterface}). 
     */
    public int set(String s);
}
