/* ------------------------------------------------------------------------- */
/*                                                                           */
/* Copyright (c) 2003 The Open Group                                         */
/*                                                                           */
/* Permission is hereby granted, free of charge, to any person obtaining a   */
/* copy of this software (the "Software"), to deal in the Software without   */
/* restriction, including without limitation the rights to use, copy,        */
/* modify, merge, publish, distribute, sublicense, and/or sell copies of     */
/* the Software, and to permit persons to whom the Software is furnished     */
/* to do so, subject to the following conditions:                            */
/*                                                                           */
/* The above copyright notice and this permission notice shall be included   */
/* in all copies or substantial portions of the Software.                    */
/*                                                                           */
/* THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS   */
/* OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF                */
/* MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.    */
/* IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY      */
/* CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT */
/* OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR  */
/* THE USE OR OTHER DEALINGS IN THE SOFTWARE.                                */
/*                                                                           */
/* ------------------------------------------------------------------------- */
/*                                                                           */
/* File revision information                                                 */
/*                                                                           */
/* $Source: /mnt/cvslocal/sdk4/java/org/opengroup/arm40/metric/ArmTranReportWithMetrics.java,v $ */
/* $Revision: 1.1 $ */
/* $Date: 2005/03/14 15:14:53 $ */
/*                                                                           */
/* ------------------------------------------------------------------------- */

package org.opengroup.arm40.metric;

import org.opengroup.arm40.tranreport.ArmTranReport;

/**
 * A subclass of <code>ArmTranReport</code> that is used if 
 * the application wishes to use metrics.
 * All the {@link org.opengroup.arm40.tranreport.ArmTranReport} 
 * rules for using <code>report()</code> apply to this interface. 
 * It extends <code>ArmTranReport</code> by adding methods to manipulate 
 * metrics. The <code>ArmMetric</code> subclass objects are bound to 
 * an <code>ArmTranReportWithMetrics</code> object when it is created.
 * This is done by specifying <code>ArmMetricGroup</code> in the 
 * <code>newArmTranReportWithMetrics()</code> method of 
 * <code>ArmMetricFactory</code>. 
 * <p/>
 * Objects implementing this interface are created using 
 * {@link ArmMetricFactory#newArmTranReportWithMetrics}.
 * 
 * @author ARM Working Group of The Open Group
 */

public interface ArmTranReportWithMetrics extends ArmTranReport {

// No Public Constructors

// Public Instance Methods

    /**
     * @return the object that contains the metadata
     * describing this transaction, including the metric definitions. 
     */
    public ArmTransactionWithMetricsDefinition 
        getTransactionWithMetricsDefinition();

    /**
     * @return the object that was bound when 
     * <code>ArmTranReportWithMetrics</code> is created. 
     * The returned value may be null.
     */
    public ArmMetricGroup getMetricGroup();
}
