/* ------------------------------------------------------------------------- */
/*                                                                           */
/* Copyright (c) 2003 The Open Group                                         */
/*                                                                           */
/* Permission is hereby granted, free of charge, to any person obtaining a   */
/* copy of this software (the "Software"), to deal in the Software without   */
/* restriction, including without limitation the rights to use, copy,        */
/* modify, merge, publish, distribute, sublicense, and/or sell copies of     */
/* the Software, and to permit persons to whom the Software is furnished     */
/* to do so, subject to the following conditions:                            */
/*                                                                           */
/* The above copyright notice and this permission notice shall be included   */
/* in all copies or substantial portions of the Software.                    */
/*                                                                           */
/* THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS   */
/* OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF                */
/* MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.    */
/* IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY      */
/* CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT */
/* OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR  */
/* THE USE OR OTHER DEALINGS IN THE SOFTWARE.                                */
/*                                                                           */
/* ------------------------------------------------------------------------- */
/*                                                                           */
/* File revision information                                                 */
/*                                                                           */
/* $Source: /mnt/cvslocal/sdk4/java/org/opengroup/arm40/tranreport/ArmTranReportFactory.java,v $ */
/* $Revision: 1.1 $ */
/* $Date: 2005/03/14 15:14:53 $ */
/*                                                                           */
/* ------------------------------------------------------------------------- */

package org.opengroup.arm40.tranreport;

import org.opengroup.arm40.transaction.ArmApplication;
import org.opengroup.arm40.transaction.ArmApplicationDefinition;
import org.opengroup.arm40.transaction.ArmID;
import org.opengroup.arm40.transaction.ArmInterface;
import org.opengroup.arm40.transaction.ArmTransactionDefinition;
import org.opengroup.arm40.transaction.ArmErrorCallback;

/**
 * Provides methods to create instances of the classes in 
 * the org.opengroup.arm40.tranreport package. An error callback method can 
 * be registered for objects created with this factory (see 
 * {@link #setErrorCallback(ArmErrorCallback)}). For additional 
 * details about error handling philosophy see the description
 * of {@link org.opengroup.arm40.transaction.ArmTransactionFactory}.
 * <p/>
 * Semantics of the factory methods are provided in the description 
 * of the individual methods below.  
 * <p/>
 * 
 * <code>ArmTranReportFactory</code> is instantiated using a class loader. 
 * The actual name of the factory implementation class is obtained from the 
 * system property whose name is provided in the 
 * {@link #propertyKey} constant.   
 * 
 * @author ARM Working Group of The Open Group
 */
public interface ArmTranReportFactory extends ArmInterface {

// Public Constants

    /**
     * name of system property holding the implementation class name.
     */
    public static final String propertyKey = "Arm40.ArmTranReportFactory";


// Public Instance Methods

    /**
     * Creates an <code>ArmApplicationRemote</code>. 
     * If <code>systemAddress</code> is <code>null</code>,
     * the addressing information for the local system is used.
     * 
     * @see org.opengroup.arm40.transaction.ArmApplication
     * 
     * @param definition metadata describing the type of the ARM application.
     *                   Must not be <code>null</code>.
     * @param group Name of the group the application belongs to.
     *              May be <code>null</code>.
     * @param instance Name this application instance is given.
     *                 May be <code>null</code>.
     * @param contextValues An array of strings providing the value parts of
     *                      (name,value) context properties.
     *                      May be <code>null</code>.
     * @param systemAddress address of the remote system the application is
     *                      executing on. 
     * @return a new <code>ArmApplicationRemote</code> instance.
     */
    public ArmApplicationRemote newArmApplicationRemote(
        ArmApplicationDefinition definition, String group, String instance,
        String[] contextValues, ArmSystemAddress systemAddress);

    /**
     * Creates an ArmSystemAddress from the specified format 
     * and the input byte array. See the {@link ArmSystemAddress} description 
     * for more details about the parameters. The length of the address data
     * is the length of <code>addressBytes</code>, if not restricted otherwise 
     * through the <code>format</code> parameter.
     * 
     * @param format the address format.
     * @param addressBytes a byte array containig the address data.
     * @param id An optional 16-byte ID associated with the identity of 
     *           the <code>ArmSystemAddress</code>. 
     * @return a new <code>ArmSystemAddress</code>
     */
    public ArmSystemAddress newArmSystemAddress(short format, 
        byte[] addressBytes, ArmID id);

    /**
     * Creates an ArmSystemAddress from the specified format 
     * and the input byte array. See the {@link ArmSystemAddress} description 
     * for more details about the parameters. The length of the address data
     * is the length of <code>addressBytes</code>, if not restricted otherwise 
     * through the <code>format</code> parameter.
     * 
     * @param format the address format.
     * @param addressBytes a byte array containig the address data.
     * @param id An optional 16-byte ID associated with the identity of 
     *           the <code>ArmSystemAddress</code>. 
     * @param offset start of the address bytes within the array.
     * @return a new <code>ArmSystemAddress</code>
     */
    public ArmSystemAddress newArmSystemAddress(short format, 
        byte[] addressBytes, int offset, ArmID id);

    /**
     * Creates an ArmSystemAddress from the specified format 
     * and the input byte array. See the {@link ArmSystemAddress} description 
     * for more details about the parameters. The length of the address data
     * is <code>length</code>, if not restricted otherwise 
     * through the <code>format</code> parameter.
     * 
     * @param format the address format.
     * @param addressBytes a byte array containig the address data.
     * @param id An optional 16-byte ID associated with the identity of 
     *           the <code>ArmSystemAddress</code>. 
     * @param offset start of the address bytes within the array.
     * @param length the number of bytes of valid address data.
     * @return a new <code>ArmSystemAddress</code>
     */
    public ArmSystemAddress newArmSystemAddress(short format, 
        byte[] addressBytes, int offset, int length, ArmID id);

    /**
     * Creates an object that represents an instance of a transaction.
     * The metadata is supplied in an <code>ArmTransactionDefinition</code>
     * object. It is scoped by an application instance, 
     * represented by <code>ArmApplication</code> (or its subclass, 
     * <code>ArmApplicationRemote</code>).
     * @param app the application instance the transaction belongs to.
     * @param definition the metadata describing the type of the transaction.
     * @return a new <code>ArmTranReport</code> instance.
     */
    public ArmTranReport newArmTranReport(ArmApplication app, 
        ArmTransactionDefinition definition);

    /**
     * Registers an error callback for objects created through this factory.
     * See the error handling philosophy comment in the description of
     * {@link org.opengroup.arm40.transaction.ArmTransactionFactory}.
     * 
     * @param errorCallback an application object implementing the
     *                      <code>ArmErrorCallback> interface.
     * @return <code>true</code> if registration is accepted.
     */
    public boolean setErrorCallback(ArmErrorCallback errorCallback);
}
