/* ------------------------------------------------------------------------- */
/*                                                                           */
/* Copyright (c) 2003 The Open Group                                         */
/*                                                                           */
/* Permission is hereby granted, free of charge, to any person obtaining a   */
/* copy of this software (the "Software"), to deal in the Software without   */
/* restriction, including without limitation the rights to use, copy,        */
/* modify, merge, publish, distribute, sublicense, and/or sell copies of     */
/* the Software, and to permit persons to whom the Software is furnished     */
/* to do so, subject to the following conditions:                            */
/*                                                                           */
/* The above copyright notice and this permission notice shall be included   */
/* in all copies or substantial portions of the Software.                    */
/*                                                                           */
/* THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS   */
/* OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF                */
/* MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.    */
/* IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY      */
/* CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT */
/* OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR  */
/* THE USE OR OTHER DEALINGS IN THE SOFTWARE.                                */
/*                                                                           */
/* ------------------------------------------------------------------------- */
/*                                                                           */
/* File revision information                                                 */
/*                                                                           */
/* $Source: /mnt/cvslocal/sdk4/java/org/opengroup/arm40/transaction/ArmApplicationDefinition.java,v $ */
/* $Revision: 1.1 $ */
/* $Date: 2005/03/14 15:14:53 $ */
/*                                                                           */
/* ------------------------------------------------------------------------- */

package org.opengroup.arm40.transaction;

/**
 * Describes the attributes of an application that do not change from one
 * instance of the application to another.
 * 
 * This provides an anchor point for associating 
 * <code>ArmTransactionDefinition</code> and <code>ArmMetricDefinition</code>
 * objects with the application.  
 * It has the following attributes, all of which are immutable: 
 * <ul>
 * <li>
 * <b>Name</b>. The maximum length is 127 characters (CIM allows 
 * 256 but ARM 4.0 C Bindings allow 128 characters, including the 
 * null-termination character, so 127 is used). The name must not be 
 * <code>null</code> or zero-length. A name should be chosen that is unique,
 * so generic names that might be used by a different development team, 
 * such as "Payroll Application", should not be used. Names should not 
 * contain trailing blank characters or consist of only blank characters.
 * </li>
 * <li>
 * (optional) <b>Identity property names</b> and <b>values</b> and 
 * <b>context property names</b> in arrays. See the discussion of 
 * identity and context property names in {@link ArmIdentityProperties}. 
 * </li>
 * <li>
 * (optional) <b>ID</b>. An optional 16-byte ID may be associated with 
 * the identity of an application definition. The returned value, which 
 * could be <code>null</code>, is the same value passed to  
 * {@link ArmTransactionFactory#newArmApplicationDefinition}. The ID 
 * value is bound to a unique combination of the application name, 
 * any identity property names and values, and any context property names. 
 * When provided, the ID may be used as a concise alias for the unique 
 * combination. It may be <code>null</code>.
 * </li>
 * </ul>
 * <p/>
 * {@link #destroy} does not, of course, destroy the 
 * <code>ArmApplicationDefinition</code> object. It does signal to the 
 * ARM implementation that the definition and all related definitions 
 * (e.g., <code>ArmTransactionDefinition</code>) within its scope are 
 * no longer needed. The normal behavior would be for the ARM implementation
 * to release its references to all those objects. If the application also
 * releases its references, the objects would be eligible for garbage 
 * collection. After <code>destroy()</code> is called, no method on any 
 * object that is scoped by the <code>ArmApplicationDefinition</code> should 
 * be called again. If a method is called, the results are unpredictable.
 * <p/>
 * Objects implementing this interface are created using 
 * {@link ArmTransactionFactory#newArmApplicationDefinition}.
 * 
 * @author ARM Working Group of The Open Group
 */

public interface ArmApplicationDefinition extends ArmInterface {

// No Public Constructors

// Public Instance Methods

    /**
     * Signal to the ARM implementation that the definition and all related
     * definitions within its scope are no longer needed.
     */
    public void destroy();

    /**
     * @return the name of this application.
     */
    public String getName();

    /**
     * @return an object describing the identity property metadata
     * associated with this application, or <code>null</code>. 
     * See the discussion in {@link ArmIdentityProperties}.
     */
    public ArmIdentityProperties getIdentityProperties();

    /**
     * @return a 16-byte ID associated with the identity of this
     * application definition, or <code>null</code>.
     */
    public ArmID getID();
}

