/* ------------------------------------------------------------------------- */
/*                                                                           */
/* Copyright (c) 2003 The Open Group                                         */
/*                                                                           */
/* Permission is hereby granted, free of charge, to any person obtaining a   */
/* copy of this software (the "Software"), to deal in the Software without   */
/* restriction, including without limitation the rights to use, copy,        */
/* modify, merge, publish, distribute, sublicense, and/or sell copies of     */
/* the Software, and to permit persons to whom the Software is furnished     */
/* to do so, subject to the following conditions:                            */
/*                                                                           */
/* The above copyright notice and this permission notice shall be included   */
/* in all copies or substantial portions of the Software.                    */
/*                                                                           */
/* THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS   */
/* OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF                */
/* MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.    */
/* IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY      */
/* CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT */
/* OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR  */
/* THE USE OR OTHER DEALINGS IN THE SOFTWARE.                                */
/*                                                                           */
/* ------------------------------------------------------------------------- */
/*                                                                           */
/* File revision information                                                 */
/*                                                                           */
/* $Source: /mnt/cvslocal/sdk4/java/org/opengroup/arm40/transaction/ArmCorrelator.java,v $ */
/* $Revision: 1.1 $ */
/* $Date: 2005/03/14 15:14:53 $ */
/*                                                                           */
/* ------------------------------------------------------------------------- */

package org.opengroup.arm40.transaction;

/**
 * Represents a correlation token passed from a calling transaction to a 
 * called transaction. 
 * The correlation token may be used to establish a calling hierarchy across 
 * processes and systems. A correlator contains a two-byte length field, 
 * a one-byte format ID, a one-byte flag field, plus it may contain other data 
 * that is used to uniquely identify an instance of a transaction. 
 * Applications do not need to understand correlator internals. See 
 * Appendix B of the ARM 4.0 Java Binding Specification for more 
 * information about correlator formats.
 * A correlation token is a maximum of 
 * {@link ArmConstants#CORR_MAX_LENGTH} bytes, including the header.
 * <p/>
 * <code>ArmCorrelator</code> is created in one of three ways: 
 * <ul>
 * <li>
 * The {@link ArmTransactionFactory#newArmCorrelator} method 
 * takes as input a byte array in network byte order, such as would be 
 * received from a caller.
 * </li>
 * <li>The {@link ArmTransaction#getCorrelator} method creates a correlator
 * object for the currently or most recently executed transaction. 
 * </li>
 * <li>
 * The {@link org.opengroup.arm40.tranreport.ArmTranReport#generateCorrelator}
 * method creates a correlator object for what is presumed to be the next 
 * transaction to be executed.
 * </li>
 * </ul>
 * <p/>
 * An application may extract the byte array in network byte order, which 
 * is the format needed to send to a called transaction, using the 
 * <code>copyBytes()</code> or <code>getBytes()</code> methods of 
 * <code>ArmToken</code>, <code>ArmCorrelator</code>'s parent interface.
 * <p/>
 * Implementations of this interface should also override 
 * <code>equals()</code> and <code>hashCode()</code> from 
 * <code>java.lang.Object</code>.
 * 
 * @author ARM Working Group of The Open Group
 */
public interface ArmCorrelator extends ArmToken {
// No Public Constructors

// Public Instance Methods 

    /**
     * indicates whether the "agent trace" flag is on in the correlator.
     * @return the status of the agent trace flag.
     */
    public boolean isAgentTrace();
        
    /**
     * indicates whether the "application trace" flag is on in the 
     * correlator.
     * @return the status of the application trace flag.
     */
    public boolean isApplicationTrace();
}
