/* ------------------------------------------------------------------------- */
/*                                                                           */
/* Copyright (c) 2003 The Open Group                                         */
/*                                                                           */
/* Permission is hereby granted, free of charge, to any person obtaining a   */
/* copy of this software (the "Software"), to deal in the Software without   */
/* restriction, including without limitation the rights to use, copy,        */
/* modify, merge, publish, distribute, sublicense, and/or sell copies of     */
/* the Software, and to permit persons to whom the Software is furnished     */
/* to do so, subject to the following conditions:                            */
/*                                                                           */
/* The above copyright notice and this permission notice shall be included   */
/* in all copies or substantial portions of the Software.                    */
/*                                                                           */
/* THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS   */
/* OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF                */
/* MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.    */
/* IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY      */
/* CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT */
/* OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR  */
/* THE USE OR OTHER DEALINGS IN THE SOFTWARE.                                */
/*                                                                           */
/* ------------------------------------------------------------------------- */
/*                                                                           */
/* File revision information                                                 */
/*                                                                           */
/* $Source: /mnt/cvslocal/sdk4/java/org/opengroup/arm40/transaction/ArmErrorCallback.java,v $ */
/* $Revision: 1.1 $ */
/* $Date: 2005/03/14 15:14:53 $ */
/*                                                                           */
/* ------------------------------------------------------------------------- */

package org.opengroup.arm40.transaction;

/**
 * An error callback interface to be implemented by the application. (optional) 
 * <p/>
 * The use of ArmErrorCallback is optional.
 * <p/>
 * <code>ArmErrorCallback</code> is different from all the other ARM 
 * interfaces because instead of the ARM implementation creating objects 
 * that implement the interface, the application creates an object that 
 * implements it. The application can create an 
 * <code>ArmErrorCallback</code> and register it with the 
 * <code>setErrorCallback()</code> method of one of the ARM factory classes.
 * If the registration is accepted, anytime a method results in an error, 
 * the ARM implementation:
 * <ul>
 * <li>
 * Sets the object's error code. This error code can be retrieved with the 
 * <code>getErrorCode()</code> method of <code>ArmInterface</code>, 
 * from which all other ARM interfaces with methods derive. 
 * </li>
 * <li>
 * Calls <code>errorCodeSet()</code> in <code>ArmErrorCallback</code>,
 * if an ArmErrorCallback has been successfully registered.
 * </li>
 * <li>
 * Returns the error code if the method that caused the error returns an 
 * error code. 
 * </li>
 * </ul>
 * There are no expected or required behaviors for the 
 * implementation of <code>errorCodeSet()</code>.
 * <p/>
 * Examples of things a callback method may do are: 
 * <ul>
 * <li>
 * Nothing.
 * </li>
 * <li>
 * Log an error. This would be a common behavior during program debug.
 * </li>
 * <li>
 * Reset the error code to zero, or set it to some other value. 
 * This is a way for an error handling policy to be implemented centrally, 
 * and communicated to the rest of the application code. 
 * 
 * @author ARM Working Group of The Open Group
 */
public interface ArmErrorCallback {

// No Public Constructors

// Public Instance Methods

    /**
     * Callback method called by the ARM implementation.
     * All parameters must contain non-<code>null</code> values.
     * 
     * @param errorObject a reference to the ARM implementation's object 
     * that detected the error. The callback method can use the 
     * <code>getErrorCode()</code> of <code>errorObject</code> to get the 
     * error code value, which will be negative.
     * @param interfaceName the name of an interface in one of the ARM 
     * specification packages.
     * @param methodName the name of a method in that interface.
     */
    public void errorCodeSet(ArmInterface errorObject, 
        String interfaceName, String methodName); 
}
