/* ------------------------------------------------------------------------- */
/*                                                                           */
/* Copyright (c) 2003 The Open Group                                         */
/*                                                                           */
/* Permission is hereby granted, free of charge, to any person obtaining a   */
/* copy of this software (the "Software"), to deal in the Software without   */
/* restriction, including without limitation the rights to use, copy,        */
/* modify, merge, publish, distribute, sublicense, and/or sell copies of     */
/* the Software, and to permit persons to whom the Software is furnished     */
/* to do so, subject to the following conditions:                            */
/*                                                                           */
/* The above copyright notice and this permission notice shall be included   */
/* in all copies or substantial portions of the Software.                    */
/*                                                                           */
/* THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS   */
/* OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF                */
/* MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.    */
/* IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY      */
/* CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT */
/* OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR  */
/* THE USE OR OTHER DEALINGS IN THE SOFTWARE.                                */
/*                                                                           */
/* ------------------------------------------------------------------------- */
/*                                                                           */
/* File revision information                                                 */
/*                                                                           */
/* $Source: /mnt/cvslocal/sdk4/java/org/opengroup/arm40/transaction/ArmIdentityProperties.java,v $ */
/* $Revision: 1.1 $ */
/* $Date: 2005/03/14 15:14:53 $ */
/*                                                                           */
/* ------------------------------------------------------------------------- */

package org.opengroup.arm40.transaction;

/**
 * Contains metadata attributes that are part of the identity of an
 * application or a transaction.
 * <p/>
 * <code>ArmIdentityProperties</code> is new in ARM 4.0. It addresses a 
 * requirement to accept a set of string (name,value) pairs that extend the 
 * concept of application and transaction identity and context.
 * <p/> 
 * ARM defines two types of properties - identity and context. The difference
 * between them is as follows:
 * <ul>
 * <li>
 * An <b>identity</b> property's <b>name and value</b> are the same for all 
 * instances of an application or transaction.
 * </li>
 * <li>
 * A <b>context</b> property's <b>name</b> is the same for all instances of 
 * an application or transaction, but a context property's <b>value</b>
 * may vary for each instance. 
 * </li>
 * </ul>
 * <code>ArmIdentityProperties</code> contains some attributes that are 
 * common to the identity of both an application and a transaction. 
 * The full identity is captured in <code>ArmApplicationDefinition</code> and 
 * <code>ArmTransactionDefinition</code>, which each adds other attributes 
 * to those listed here. All these attributes are immutable. 
 * The common attributes include: 
 * <ul>
 * <li>
 * A set of identity names (maximum of 20; maximum length of 127 characters).
 * </li<
 * <li>
 * A set of identity values (maximum of 20; maximum length of 255 characters).
 * </li>
 * <li>
 * A set of context names (maximum of 20; maximum length of 127 characters).
 * The context values may change with each instance so they are not part of 
 * the identity. The context values are in ArmApplication or ArmTransaction.
 * </li>
 * </ul>
 * Property names and values are in arrays. A property name and value form 
 * a (name,value) pair. The array index of a property value in the value 
 * array is bound to the property name at the same index in the name array. 
 * Moving the (name,value) pair to a different index does not affect the 
 * identity of the application. For example, if an application is registered
 * once with a name A and a value X in array indices 0 and once with the 
 * same name and value in array indices 1, the registered identity has not 
 * changed.
 * <p/>
 * If a name is repeated in the array, the name and its corresponding value
 * are ignored, and the first instance of the name in the array (and its
 * corresponding value) is used. If the pointer is null or points to a 
 * zero-length string, the (name,value) pair is ignored. Names should not 
 * contain trailing blank characters or consist of only blank characters.
 * <p/>
 * The names of identity and context properties can be any string, with 
 * one exception. Strings beginning with the four characters 
 * "<code>ARM:</code>" are reserved for the ARM specification. The 
 * specification will define names with known semantics using this prefix. 
 * One name format is currently defined. Any name beginning with the 
 * eight-character prefix "<code>ARM:CIM:</code>" represents a name defined
 * using the DMTF CIM (Distributed Management Task Force Common 
 * Information Model) naming rules. For example, 
 * "<code>ARM:CIM:CIM_SoftwareElement.Name</code>" indicates that the 
 * property value has the semantics of the Name property of the 
 * <code>CIM_SoftwareElement</code> class. It is anticipated that additional 
 * naming semantics are likely to be added in the future. 
 * <p/>
 * Objects implementing this interface are created using 
 * {@link ArmTransactionFactory#newArmIdentityProperties}.
 * 
 * @author ARM Working Group of The Open Group
 */
public interface ArmIdentityProperties extends ArmInterface {

// No Public Constructors

// Public Instance Methods

    /**
     * @param index the index of the identity name to be returned.
     * @return the string (the <code>name</code> part of the (name,value) 
     * identity property) at the specified array index. The returned value 
     * will be <code>null</code> if either the name or value at 
     * the index is set to null. 
     */
    public String getIdentityName(int index);

    /**
     * @param index the index of the identity value to be returned.
     * @return the string (the <code>value</code> part of the (name,value) 
     * identity property) at the specified array index. The returned value 
     * will be <code>null</code> if either the name or value at 
     * the index is set to null. 
     */
    public String getIdentityValue(int index);
    
    /**
     * @param index the index of the context name to be returned.
     * @return the string (the <code>name</code> part of the (name,value) 
     * context property) at the specified array index. The returned value 
     * may be <code>null</code>. 
     */
    public String getContextName(int index);
}
