/* ------------------------------------------------------------------------- */
/*                                                                           */
/* Copyright (c) 2003 The Open Group                                         */
/*                                                                           */
/* Permission is hereby granted, free of charge, to any person obtaining a   */
/* copy of this software (the "Software"), to deal in the Software without   */
/* restriction, including without limitation the rights to use, copy,        */
/* modify, merge, publish, distribute, sublicense, and/or sell copies of     */
/* the Software, and to permit persons to whom the Software is furnished     */
/* to do so, subject to the following conditions:                            */
/*                                                                           */
/* The above copyright notice and this permission notice shall be included   */
/* in all copies or substantial portions of the Software.                    */
/*                                                                           */
/* THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS   */
/* OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF                */
/* MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.    */
/* IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY      */
/* CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT */
/* OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR  */
/* THE USE OR OTHER DEALINGS IN THE SOFTWARE.                                */
/*                                                                           */
/* ------------------------------------------------------------------------- */
/*                                                                           */
/* File revision information                                                 */
/*                                                                           */
/* $Source: /mnt/cvslocal/sdk4/java/org/opengroup/arm40/transaction/ArmIdentityPropertiesTransaction.java,v $ */
/* $Revision: 1.1 $ */
/* $Date: 2005/03/14 15:14:53 $ */
/*                                                                           */
/* ------------------------------------------------------------------------- */

package org.opengroup.arm40.transaction;

/**
 * Extends <code>ArmIdentityProperties</code> for transactions by adding a
 * URI property.
 * Unlike the other identity properties, the URI property is implicitly 
 * named.
 * <p/> 
 * Like other identity properties, it is the same for all instances of the 
 * same transaction, and is immutable. In practice, this means that the 
 * URI value may be truncated from the URI that is actually used. In 
 * particular, parameters that are appended to the end of a URI will often 
 * be truncated because they are often different each time the URI is 
 * invoked. In this case, the parameters might be provided as part of the
 * URI context value of an <code>ArmTransaction</code> object.
 * <p/>
 * Objects implementing this interface are created using 
 * {@link ArmTransactionFactory#newArmIdentityPropertiesTransaction}.
 *  
 * @author ARM Working Group of The Open Group
 */
public interface ArmIdentityPropertiesTransaction extends ArmIdentityProperties {

// No Public Constructors

// Public Instance Methods

    /**
     * @return the string representing the URI value, if any. 
     * The maximum length is 
     * {@link ArmConstants#PROPERTY_URI_MAX_LENGTH} characters. 
     * The returned value will be <code>null</code> if the value is set 
     * to <code>null</code>.
     */
    public String getURIValue();
}
