/* ------------------------------------------------------------------------- */
/*                                                                           */
/* Copyright (c) 2003 The Open Group                                         */
/*                                                                           */
/* Permission is hereby granted, free of charge, to any person obtaining a   */
/* copy of this software (the "Software"), to deal in the Software without   */
/* restriction, including without limitation the rights to use, copy,        */
/* modify, merge, publish, distribute, sublicense, and/or sell copies of     */
/* the Software, and to permit persons to whom the Software is furnished     */
/* to do so, subject to the following conditions:                            */
/*                                                                           */
/* The above copyright notice and this permission notice shall be included   */
/* in all copies or substantial portions of the Software.                    */
/*                                                                           */
/* THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS   */
/* OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF                */
/* MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.    */
/* IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY      */
/* CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT */
/* OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR  */
/* THE USE OR OTHER DEALINGS IN THE SOFTWARE.                                */
/*                                                                           */
/* ------------------------------------------------------------------------- */
/*                                                                           */
/* File revision information                                                 */
/*                                                                           */
/* $Source: /mnt/cvslocal/sdk4/java/org/opengroup/arm40/transaction/ArmInterface.java,v $ */
/* $Revision: 1.1 $ */
/* $Date: 2005/03/14 15:14:53 $ */
/*                                                                           */
/* ------------------------------------------------------------------------- */

package org.opengroup.arm40.transaction;

/**
 * The root of the inheritance hierarchy for almost all ARM interfaces. 
 * <p/>
 * It provides a common way to handle errors. If a method invocation on any 
 * ARM object causes an error, the error code returned by the object's 
 * {@link #getErrorCode} will be negative. If no error occurs, the error
 * code is zero. Several methods also return the error code as an 
 * <code>int</code> return value. If an error occurs in a factory method 
 * (e.g., a method in <code>ArmTransactionFactory</code>), the error code 
 * is set in both the factory object and the newly created object. The 
 * implementation of the object has sole discretion as to whether a method 
 * results in an error. 
 * <p/>
 * The error code may change any time a method of the object is executed. 
 * Executing a method overrides the previous error code value. The only 
 * methods that will never change the error code are 
 * <code>getErrorCode()</code> and <code>getErrorMessage()</code>. 
 * If multiple threads are processing the same object simultaneously, the 
 * results are unpredictable. An error code set as a result of an operation 
 * in method X could be replaced by an operation in method Y before 
 * thread X executes <code>getErrorCode()</code>. 
 * <p/>
 * The error code can also be set with {@link #setErrorCode}. This is a way 
 * for the application to reset or change the error code. It would most 
 * typically be used in a callback registered with the ARM implementation's 
 * factory objects used to create ARM objects on behalf of the application. 
 * In this way the application can implement a central error handling 
 * policy in the callback. A value set with <code>setErrorCode()</code>
 * in a callback overwrites the previous value (i.e., the value that caused 
 * the callback to be made). 
 * <p/>
 * For any non-zero error code returned by an object, the application can 
 * request from the same object a string message describing the error 
 * using {@link #getErrorMessage}. If the object does not support the 
 * function or does not recognize the error code, it returns 
 * <code>null</code>. 
 * 
 * @author ARM Working Group of The Open Group
 */
public interface ArmInterface {

// No Public Constructors

// Public Instance Methods

    /**
     * @return last error code set for this object as a negative value. 
     * Zero, if no error code is set.
     */
    public int getErrorCode();

    /**
     * @param errorCode the error code to be set for this object.
     * @return the error code provided in <code>errorCode</code>.
     */
    public int setErrorCode(int errorCode); 

    /**
     * @param errorCode an error code retrieved from this object.
     * @return a string describing the error for <code>errorCode</code>,
     * or <code>null</code>. 
     */
    public String getErrorMessage(int errorCode);
}
