/* ------------------------------------------------------------------------- */
/*                                                                           */
/* Copyright (c) 2003 The Open Group                                         */
/*                                                                           */
/* Permission is hereby granted, free of charge, to any person obtaining a   */
/* copy of this software (the "Software"), to deal in the Software without   */
/* restriction, including without limitation the rights to use, copy,        */
/* modify, merge, publish, distribute, sublicense, and/or sell copies of     */
/* the Software, and to permit persons to whom the Software is furnished     */
/* to do so, subject to the following conditions:                            */
/*                                                                           */
/* The above copyright notice and this permission notice shall be included   */
/* in all copies or substantial portions of the Software.                    */
/*                                                                           */
/* THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS   */
/* OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF                */
/* MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.    */
/* IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY      */
/* CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT */
/* OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR  */
/* THE USE OR OTHER DEALINGS IN THE SOFTWARE.                                */
/*                                                                           */
/* ------------------------------------------------------------------------- */
/*                                                                           */
/* File revision information                                                 */
/*                                                                           */
/* $Source: /mnt/cvslocal/sdk4/java/org/opengroup/arm40/transaction/ArmTransactionDefinition.java,v $ */
/* $Revision: 1.1 $ */
/* $Date: 2005/03/14 15:14:53 $ */
/*                                                                           */
/* ------------------------------------------------------------------------- */

package org.opengroup.arm40.transaction;

/**
 * Contains the metadata that is the same for all instances of a transaction 
 * type.
 * <p/>
 * The metadata can be used to describe types of instances represented by 
 * <code>ArmTransaction</code> or <code>ArmTranReport</code>). 
 * <code>ArmTransactionDefinition</code> has the following attributes, 
 * all of which are immutable:
 * <ul>
 * <li>
 * The <b>definition of the application</b> that contains the transaction. 
 * It must not be <code>null</code>.
 * </li>
 * <li>
 * The <b>name</b> of the transaction (maximum 127 characters).
 * </li>
 * <li>
 * (optional) <b>Identity property names</b> and <b>values</b> and 
 * <b>context property names</b> in arrays. 
 * See the discussion of identity and context property names in 
 * {@link ArmIdentityProperties}.
 * </li>
 * <li>
 * (optional) <b>ID</b>. An optional 16-byte ID may be associated with 
 * the identity of a transaction definition. The returned value, which 
 * could be <code>null</code>, is the same value passed to the 
 * <code>newArmTransactionDefinition()</code> method of 
 * <code>ArmTransactionFactory</code>. The ID value is bound to a unique 
 * combination of the application identity (represented by 
 * <code>ArmApplicationDefinition</code>), transaction name, any URI 
 * identity property, any identity property names and values, 
 * and any context property names. When provided, the ID may be used as 
 * a concise alias for the unique combination. It may be 
 * <code>null</code>.
 * </li>
 * </ul>
 * <p/>Objects implementing this interface are created using
 * {@link ArmTransactionFactory#newArmTransactionDefinition}.
 * 
 * @author ARM Working Group of The Open Group
 */
public interface ArmTransactionDefinition extends ArmInterface {

// No Public Constructors

// Public Instance Methods

    /**
     * @return the metadata describing the contaning application.
     */
    public ArmApplicationDefinition getApplicationDefinition();

    /**
     * @return a 16-byte ID associated with the identity of this
     *         application definition, or <code>null</code>.
     */
    public ArmID getID();

    /**
     * @return an object describing the identity property metadata
     *         associated with this transaction, or <code>null</code>. 
     *         See the discussion in {@link ArmIdentityProperties}.
     */
    public ArmIdentityPropertiesTransaction getIdentityProperties();

    /**
     * @return the name of this transaction.
     */
    public String getName();
}
