/* ------------------------------------------------------------------------- */
/*                                                                           */
/* Copyright (c) 2003 The Open Group                                         */
/*                                                                           */
/* Permission is hereby granted, free of charge, to any person obtaining a   */
/* copy of this software (the "Software"), to deal in the Software without   */
/* restriction, including without limitation the rights to use, copy,        */
/* modify, merge, publish, distribute, sublicense, and/or sell copies of     */
/* the Software, and to permit persons to whom the Software is furnished     */
/* to do so, subject to the following conditions:                            */
/*                                                                           */
/* The above copyright notice and this permission notice shall be included   */
/* in all copies or substantial portions of the Software.                    */
/*                                                                           */
/* THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS   */
/* OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF                */
/* MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.    */
/* IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY      */
/* CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT */
/* OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR  */
/* THE USE OR OTHER DEALINGS IN THE SOFTWARE.                                */
/*                                                                           */
/* ------------------------------------------------------------------------- */
/*                                                                           */
/* File revision information                                                 */
/*                                                                           */
/* $Source: /mnt/cvslocal/sdk4/java/org/opengroup/arm40/transaction/ArmUser.java,v $ */
/* $Revision: 1.1 $ */
/* $Date: 2005/03/14 15:14:53 $ */
/*                                                                           */
/* ------------------------------------------------------------------------- */

package org.opengroup.arm40.transaction;

/**
 * Represents a user on behalf of whom a transaction is executed.
 * It has the following attributes, all of which are immutable:
 * <ul>
 * <li>
 * <b>Name</b>: The maximum length is 127 characters (CIM allows 256 but 
 * ARM 2.0 allows 128 bytes, including the null-termination character, 
 * so 127 is used). The name must not be <code>null</code> or zero-length.
 * </li>
 * <li>
 * (optional) A 16-byte <b>ID</b> is optionally associated with each 
 * <code>ArmUser</code>. It is provided by the application. If the value is 
 * <code>null</code>, no ID was provided.
 * </li>
 * </ul>
 * 
 * <p/>Objects implementing this interface are created using
 * {@link ArmTransactionFactory#newArmUser}.
 * 
 * @author ARM Working Group of The Open Group
 */
public interface ArmUser extends ArmInterface {

// No Public Constructors

// Public Instance Methods

    /**
     * @return the name of the user.
     */
    public ArmID getID();

    /**
     * @return a 16-byte ID associated with the identity of this
     *         user, or <code>null</code>.
     */
    public String getName();
}
